﻿// Copyright 2021 Esri
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

using Esri.ArcGISRuntime.Geometry;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SearchForAnAddress
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        public MainWindow()
        {
            InitializeComponent();

            // Create a point centered on the Santa Monica mountains in Southern California.
            // Longitude=118.805 degrees West, Latitude=34.027 degrees North
            var mapCenterPoint = new Esri.ArcGISRuntime.Geometry.MapPoint(-118.805, 34.027, Esri.ArcGISRuntime.Geometry.SpatialReferences.Wgs84);

            // Create a viewpoint for the initial display of the map.
            // Use the point defined above and a scale of 1:100,000
            MainMapView.SetViewpoint(new Esri.ArcGISRuntime.Mapping.Viewpoint(mapCenterPoint, 100_000));
        }

        private async void SearchAddressButton_Click(object sender, RoutedEventArgs e)
        {

            // Get the MapViewModel from the page (defined as a static resource).
            var viewModel = (MapViewModel)FindResource("MapViewModel");
            if(viewModel == null) { return; }

            // Call SearchAddress on the view model, pass the address text and the map view's spatial reference.
            var spatialReference = MainMapView.SpatialReference;
            if(spatialReference== null) { return; }
            MapPoint? addressPoint = await viewModel.SearchAddress(AddressTextBox.Text, spatialReference);

            // If a result was found, center the display on it.
            if (addressPoint != null)
            {
                await MainMapView.SetViewpointCenterAsync(addressPoint);
            }

        }

    }
}

